# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_prr_global_optspecs
	string join \n config= h/help V/version
end

function __fish_prr_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_prr_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_prr_using_subcommand
	set -l cmd (__fish_prr_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c prr -n "__fish_prr_needs_command" -l config -d 'Path to config file' -r -F
complete -c prr -n "__fish_prr_needs_command" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c prr -n "__fish_prr_needs_command" -s V -l version -d 'Print version'
complete -c prr -n "__fish_prr_needs_command" -f -a "get" -d 'Get a pull request and begin a review'
complete -c prr -n "__fish_prr_needs_command" -f -a "edit" -d 'Open an existing review in $EDITOR'
complete -c prr -n "__fish_prr_needs_command" -f -a "submit" -d 'Submit a review'
complete -c prr -n "__fish_prr_needs_command" -f -a "apply" -d 'Apply a pull request to the working directory'
complete -c prr -n "__fish_prr_needs_command" -f -a "status" -d 'Print a status summary of all known reviews'
complete -c prr -n "__fish_prr_needs_command" -f -a "remove" -d 'Remove a review'
complete -c prr -n "__fish_prr_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c prr -n "__fish_prr_using_subcommand get" -s f -l force -d 'Ignore unsubmitted review checks'
complete -c prr -n "__fish_prr_using_subcommand get" -l open -d 'Open review file in $EDITOR after download'
complete -c prr -n "__fish_prr_using_subcommand get" -s h -l help -d 'Print help'
complete -c prr -n "__fish_prr_using_subcommand edit" -s h -l help -d 'Print help'
complete -c prr -n "__fish_prr_using_subcommand submit" -s d -l debug
complete -c prr -n "__fish_prr_using_subcommand submit" -s h -l help -d 'Print help'
complete -c prr -n "__fish_prr_using_subcommand apply" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c prr -n "__fish_prr_using_subcommand status" -s n -l no-titles -d 'Hide column titles from output'
complete -c prr -n "__fish_prr_using_subcommand status" -s h -l help -d 'Print help'
complete -c prr -n "__fish_prr_using_subcommand remove" -s f -l force -d 'Ignore unsubmitted review checks'
complete -c prr -n "__fish_prr_using_subcommand remove" -s s -l submitted -d 'Remove submitted reviews in addition to provided reviews'
complete -c prr -n "__fish_prr_using_subcommand remove" -s h -l help -d 'Print help'
complete -c prr -n "__fish_prr_using_subcommand help; and not __fish_seen_subcommand_from get edit submit apply status remove help" -f -a "get" -d 'Get a pull request and begin a review'
complete -c prr -n "__fish_prr_using_subcommand help; and not __fish_seen_subcommand_from get edit submit apply status remove help" -f -a "edit" -d 'Open an existing review in $EDITOR'
complete -c prr -n "__fish_prr_using_subcommand help; and not __fish_seen_subcommand_from get edit submit apply status remove help" -f -a "submit" -d 'Submit a review'
complete -c prr -n "__fish_prr_using_subcommand help; and not __fish_seen_subcommand_from get edit submit apply status remove help" -f -a "apply" -d 'Apply a pull request to the working directory'
complete -c prr -n "__fish_prr_using_subcommand help; and not __fish_seen_subcommand_from get edit submit apply status remove help" -f -a "status" -d 'Print a status summary of all known reviews'
complete -c prr -n "__fish_prr_using_subcommand help; and not __fish_seen_subcommand_from get edit submit apply status remove help" -f -a "remove" -d 'Remove a review'
complete -c prr -n "__fish_prr_using_subcommand help; and not __fish_seen_subcommand_from get edit submit apply status remove help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
